@@ -5,32 +5,15 @@ use warnings;
 
 use Carp qw/croak/;
 
-use Types::Standard qw(Int Num Str);
-
 use Moo;
 use strictures 2;
 use namespace::clean;
 
+with 'OpenAI::API::ConfigurationRole';
+with 'OpenAI::API::UserAgentRole';
 with 'OpenAI::API::ResourceDispatcherRole';
 
-our $VERSION = 0.24;
-
-my $DEFAULT_API_BASE = 'https://api.openai.com/v1';
-
-has api_key  => ( is => 'rw', isa => Str, default => sub { $ENV{OPENAI_API_KEY} }, required => 1 );
-has api_base => ( is => 'rw', isa => Str, default => sub { $ENV{OPENAI_API_BASE} // $DEFAULT_API_BASE }, );
-has timeout  => ( is => 'rw', isa => Num, default => sub { 60 } );
-has retry    => ( is => 'rw', isa => Int, default => sub { 3 } );
-has sleep    => ( is => 'rw', isa => Num, default => sub { 1 } );
-
-has user_agent => ( is => 'lazy' );
-
-sub _build_user_agent {
-    my ($self) = @_;
-    $self->{user_agent} = LWP::UserAgent->new( timeout => $self->timeout );
-}
-
-1;
+our $VERSION = 0.25;
 
 __END__
 
@@ -62,9 +45,21 @@ OpenAI::API - Perl interface to OpenAI API
         instruction => 'Fix the spelling mistakes',
     );
 
+    my $images = $openai->image_create(
+        prompt => 'A cute baby sea otter',
+        n      => 2,
+        size   => '1024x1024',
+    );
+
+    my $models = $openai->files();
+    my $model  = $openai->file_retrieve( item_id => 'file-xxxxxxxxxx' );
+
+    my $models = $openai->models();
+    my $model  = $openai->model_retrieve( model => 'text-davinci-003' );
+
     my $moderations = $openai->moderations(
         model => 'text-moderation-latest',
-        input => 'I want to kill them.',
+        input => 'I like turtles',
     );
 
 =head1 DESCRIPTION
@@ -205,6 +200,42 @@ Mandatory parameters:
 
 More info: L<OpenAI::API::Resource::Embedding>
 
+=head2 image_create()
+
+Creates an image given a prompt.
+
+Mandatory parameters:
+
+=over 4
+
+=item * prompt
+
+=back
+
+More info: L<OpenAI::API::Resource::Image::Generation>
+
+=head2 models()
+
+Lists the currently available models, and provides basic information
+about each one such as the owner and availability.
+
+More info: L<OpenAI::API::Resource::Model::List>
+
+=head2 model_retrieve()
+
+Retrieves a model instance, providing basic information about the model
+such as the owner and permissioning.
+
+Mandatory parameters:
+
+=over 4
+
+=item * model
+
+=back
+
+More info: L<OpenAI::API::Resource::Model::Retrieve>
+
 =head2 moderations()
 
 Given a input text, outputs if the model classifies it as violating
